#!/usr/bin/env python
# -*- coding: utf-8 -*-
# $Id: AttachSettingsTest.py 11172 2018-07-16 09:31:00Z Lavender $
#
# Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
#
# Licensed under the Proprietary License,
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at our web site.
#
# See the License for the specific language governing permissions and
# limitations under the License.
#
# $Author: Lavender $ (last)
# $Date: 2018-07-16 18:31:00 +0900 (週一, 16 七月 2018) $
# $Revision: 11172 $

from django.test import TestCase
from Iuno.test import RemoteTestCaseMixin

class TestOscarDemo(TestCase, RemoteTestCaseMixin):
    
    TEST_URL = "http://oscar.nuwainfo.com"
    TEST_SETTINGS = "tests.TestSettings"
        

if __name__ == "__main__":
    testOscarDemo = TestOscarDemo()
    testOscarDemo.runTest()